#ifndef TRANSITION_H
#define TRANSITION_H

#include "gliv-image.h"

void transition(GlivImage * im);
gboolean is_in_transition(void);

#endif
